bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 25. Aventiure
___________________________________________________
| ### <Nv> laze wir beliben wi si gefvren hie ### hochgemvte recken di gefvrn nie ### so rehte herliche in deheines chveneges lant ### si heten swaz si wolden beidiv waffen vnt gewant ### Der vogt von dem Rine chleidete sine man ### sehzech vnd tvsent als ich vernomen han ### vnd niwen tvsent chnehte gegen der hohgezit ### di si da heime liezen di beweinetenz sit
###### 1505 | ### Do trvch man div gereite ce Wormez veber den hoff ### do sprach da von Spyre ein alter bisschoff ### zv der schoenen Vten vnser frivnde wellent varn ### gegen der hohgezite got mvez ir ere da bewarn
| ### Do sprach zv zir chinden div edel Vte ### ir soldet hie beliben helde gvte ### mir ist getrovmet hinte von angestlicher not ### wi allez diz gefvegele in disem lande wære tot
###### 1507 | ### Swer sich an trovme wendet sprach do Hagene ### der enweiz der rehten mære niht ce sagene ### wenn ez im ze eren vollechlichen ste ### ich wil daz min herre ze hove nach vrlovbe ge
###### 1508 | ### Wir svln gerne riten in Ecelen lant ### da mach wol dienen chvenegen gvter <held> hant ### da wir da schowen mvezen Chriemhilde <hohgezit> ### Hagen riet di reise iedoch gerov ez in sit
| ### Er hetez widerraten want daz Gernot ### mit vngefvegen worten <im> also missebot ### er mant in Sifrides vrovn Criemhilden man ### er sprach da von wil Hagene di grozen hovereise lan
###### 1510 | ### Do sprach von Tronege Hagene dvrh vorhte ich nine tvo ### swenne ir gebietet helde so svlt ir griffen zvo ### ia rit ich mit iv gerne in Ecelen lant ### sit wart von im verhowen vil manich helm vnde rant
###### 1511 | ### Div siff bereitet waren da was vil manech man ### swaz si chleider heten div trvch man dar an ### si warn vmmvezech vor abendens zit ### si hvoben sich von hvse vil harte vroeliche sit
| ### Gezelt vnde hvetten spien man an daz gras ### anderthalp des Rines do daz geschehen was ### der kvenech bat noch beliben daz sin vil schoene wip ### si trvote noch des nahtes den sinen wætlichen lip [365b]
###### 1513 | ### Pvsvnen floytiern hvp sich des morgens frv ### dar si varn solden da bereiten si sich zv ### swer liep heten arme der trvote frivndes lip ### des schet sit vil mit leide des kvnech Ecelen wip
###### 1514 | ### Div chint der schoenen Vten di heten einen man ### chvene vnd getriwe do si wolden dan ### do sagt er dem kvenege tovgen sinen mvt ### er sprach des mvoz ich trvren daz ir di hovereise tvt
| ### Er was geheizen Rvmolt vnd was ein helt cer hant ### er sprach wem welt ir lazen livte vnd ovch div lant ### daz niemen chan erwenden iv recken iwern mvt ### div Criemhilden mære nie gedvhten mich gvt
###### 1516 | ### Daz lant si dir bevolhen vnt min kindelin ### vnt diene wol den vrowen daz ist der wille min ### swen dv sehest weinen dem troeste sinen lip ### iane getvt vns nimmer des kvenech Eceln wip
###### 1517 | ### Div ross bereitet waren den kvenegen vnd ir man ### mit minnechlichem chvessen schiet vil maniger dan ### dem in hohem mvte lebte da der lip ### daz mvose sit beweinen vil manich wætlichez wip
| ### Do man di snellen recken cen rossen sah gan ### do chos man vil der vrowen trvrechlichen stan ### daz ir vil langenz scheiden sagt in vil wol ir mvt ### vf grozen schaden ce chomene daz herce niemen sanfte tvt
###### 1519 | ### Di snellen Bvergonden sich vz hvoben ### do wart in dem lande ein michel voben ### beidenthalp der berge weinte wip vnd man ### swi dort ir volch getæte si fvren vroeliche dan
###### 1520 | ### Di Nibelvnges helde chomen mit in dan ### in tvsent halspergen ce hvs si heten lan ### vil manige schoene vrowen di gesahen si nimmer me ### di Sifrides wnden taten Criemhilde we
| ### Do sicheten si ir reise gegen dem <Mevne> dan ### vf dvrch Oster vranchen di Gventheres man ### dar leite si do Hagene dem was ez wol bechant ### ir marschalk was Danchwart der helt von Bvergonden lant
###### 1522 | ### Do si von <Ostervranchen> gegen Salvelde ritten ### do mohte man si chiesen an herlichen siten ### di fversten vnt ir mage di helde lobesam ### an dem [366a] zwelften morgen der kvenich an di Tvnowe quam
###### 1523 | ### Do reit von Tronege <Hagen> zaller vorderost ### er was den Nibelvngen ein helflicher trost ### do derbeizte der degen chvene nider vf den sant ### sin ross er harte balde zv zeinem bovme gebant
| ### Daz wazzer was engozen div sciff verborgen ### ez ergie den Nibelvngen ze grozen sorgen ### wi si chomen vebere der wach was in ze breit ### do erbeizte zv der erden vil manich ritter gemeit
###### 1525 | ### Leide sprach do Hagene mach dir wol hie geschehen ### voget von dem Rine nv maht dv selbe sehen ### daz wazer ist engozen vil starch ist im sin flvot ### ia wæne wir verliesen noch hivte hie manigen helt gvt
###### 1526 | ### Waz wizet ir mir Hagene sprach der kvenech her ### dvrh iwer selbes tvgende vntroestet vns niht mer ### den fvrt svlt ir vns svchen hinveber an daz lant ### daz wir von hinnen bringen beidiv ross vnt ovch gewant
| ### Ian ist mir sprach Hagene min leben niht so leit ### daz ich mich welle ertrenchen in disen venden breit ### ê sol von minen handen ersterben manich man ### in Ecelen landen des ich vil gvten willen han
###### 1528 | ### Belibet bi dem wazer ir stolzen ritter gvt ### ich wil di vergen svchen selbe bi der flvot ### di vns bringen vebere in Gelfrates lant ### do nam der starche Hagene sinen gvten schildes rant
###### 1529 | ### Er was vil wol gewaffent den schilt er dannen trvch ### sinen helm vf gebvnden lieht was er genvch ### do trvg er ob der brvenne ein waffen also breit ### daz ce beden eken harte vreislichen sneit
| ### Do svcht er nah den vergen wider vnd dan ### er horte wazer giezen losen er began ### in einem schoenem brvnnen daz taten wisiv wip ### di wolden sih da chvelen vnd badeten ir lip
###### 1531 | ### Hagen wart innen er sleich in tovgen nach ### do si daz versvnnen do wart in dannen gach ### daz si im entrvnnen des waren si vil her ### er nam in ir [366b] gewæte der helt enschadete in niht mer
###### 1532 | ### Do sprach daz eine merewib Hadebvrch was si genant ### edel ritter Hagene wir tvon <iv> hie bechant ### swenne ir vns degen chvene gebet widr vnser wat ### wi iv ze den Hivnen disiv hovereise ergat
| ### Si swebten sam di vogele vor im vf der flvt ### des dvhten in ir sinne starch vnd gvt ### swaz si im sagen wolden er gelovtez deste baz ### des er do hinz in gerte vil wol bescheideten si im daz
###### 1534 | ### Si sprach ir mvegt wol riten in Eceln lant ### des setze ich iv ce bvergen mine triwe hi ce hant ### daz helde nie gefvoren in deheiniv riche baz ### nach also grozen eren nv gelovbet wærliche daz
###### 1535 | ### Der rede was do Hagene in sinem hercen her ### do gap er in ir chleider vnd svmte sich niht mer ### do si do an geliten ir wnderlich gewant ### do sageten si im rehte di reise in Ecelen lant
| ### Do sprach daz ander merewip div hiez Sigelint ### ich wil dich warnen Hagen daz Aldrianes chint ### dvrh der wæte liebe hat min mvome dir gelogen ### chvemestv hin cen Hivnen so bistv sere betrogen
###### 1537 | ### Ia soltv cheren widere daz ist dir an der zit ### wand ir helde chvene also geladet sit ### daz ir sterben mvezet in Eceln lant ### swelhe dar geritent di habent den tot an der hant
###### 1538 | ### Do sprach aber Hagene ir trieget ane not ### wi moehtez sich gefvegen daz wir alle tot ### solden da beliben dvrh iemens haz ### si begonden im div mære sagen chventlicher baz
| ### Do sprach aber div eine ez mvz also wesen ### daz iwer deheiner chan da niht genesen ### niwan des chveneges kappelan daz ist vns wol bechant ### der chvemet gesvnt widere in daz Gventheres lant
###### 1540 | ### Do sprach in grimmem mvote der chvene Hagene ### daz wære minen [367a] herren mvelich ce sagene ### daz wir alle cen Hivnen solden vliesen den lip ### noch zeige vns verz wazer daz aller wiseste wip
###### 1541 | ### Si sprach sit dv der verte niht welles haben rat ### <swa> obene bi dem wazer ein herberge stat ### da inne ist ein verge vnd niender anderswa ### der mære der er vragte der gelovbet er sich da
| ### Dem vngemvotem rechen sprach div eine nach ### nv bitet noch her Hagene ia ist iv gar ze gach ### ver nemet noch div mære wir chvmet veber sant ### dirre marcherre der ist Else genant
###### 1543 | ### Sin brvoder ist geheizen der degen Gelfprat ### ein herre in Beyerlande wi mvelich ez iv stat ### welt ir dvrh sine marche ir svlt ivh wol bewarn ### vnd svlt ovch mit dem vergen vil bescheidenliche varn
###### 1544 | ### Der ist so grimmes mvotes er lat ivch niht genesen ### iren welt bi dem helde mit gvoten sinnen wesen ### welt ir daz vber er <ivh> fvere so gebet im den solt ### er hvetet disses landes vnd ist Gelpfrade holt
| ### Vnde chvom er niht bezite so rvffet veber flvt ### vnt ieht ir heizet Amelrich der was ein helt gvt ### der dvrch fientschepfte rvomte dizze lant ### so chvmt iv der verge swenne im der nam wirt genant
###### 1546 | ### Der vebermvte Hagene der vrowen do neich ### ern redete niht mere wan daz er vaste sweich ### do gie er bi dem wazer fver sich an den sant ### da er anderthalben ein herberge vant
###### 1547 | ### Er begonde vaste rvoffen hin veber den flvt ### nv hol mich hi verge sprach der degen gvt ### so gip ich dir ce miete einen bovch von golde rot ### ia ist mir dirre verte daz wizest wærliche not
| ### Der verge was so riche daz im niht dienen zam ### da von er lon selten von iemen da genam ### ovch waren sine chnehte vil harte hohgemvt ### noh stvnt allez Hagen eine disehalp der flvt
###### 1549 | ### Do rvffte er mit der chreffte daz al der wag erdoz ### wan des heldes sterche was michel vnd groz ### nv hol mich Amelrichen ich pin der Elsn [367b] man ### der dvrch starche fintschaft. von <disem> lande entran
###### 1550 | ### Vil hohe an dem swerte einen bovch er im bot ### lieht vnd schoene was er von golde rot ### daz man in veber fvrte in Gelpfrades lant ### der vebermvte verge nam selb daz Rvder an di hant
| ### Ovch was der selbe verge nivlich gehit ### div gvf nach grozem gvte vil boese ende git ### do wold er verdienen daz Hagenen golt so rot ### des leid er von dem degene den swertgrimmigen tot
###### 1552 | ### Der verge ilte genote hin vber an den sant ### den er dannen horte do er des niht evant ### do zvrnde er ernslichen als er Hagenen sach ### vil harte grimmechlich er zv dem degen sprach
###### 1553 | ### Ir mvget wol sin gezeizen benamen Amelrich ### des ich mich hie verwæne dem sit ir vngelich ### <von> vater vnd von mvter was er der brvder min ### nv ir mich betrogen habt ir mvezet disehalp sin
###### 1554 | ### <nein> dvrch got den richen sprach do Hagene ### ich bin ein recke vremde vnt sorge vff degene ### <Nv> nemet hin vrivntliche hivte minen solt ### daz ir mich vberfvret ich pin iv wærlichen holt
###### 1555 | ### <do> sprach abe der verge des mach niht gesin ### ez habent fiande di lieben herren min ### <dar vmbe> ich niemen vremden fvere in diz lant ### so liebe dir si ce lebene so trit vil balde vz an den sant
###### 1556 | ### <nvne> tvtes <niht> sprach Hagene wan trvrech ist min mvt ### nemet von mir ce minne diz golt vil gvt ### vnt fvret vns veber tvsent ross vnt also manigen man ### do sprach der grimme verge ez wirdet nimmer getan
| ### Er hvp ein starchez rvder michel vnd breit ### er slvch vf Hagenen des wart er vngemeit ### daz er in dem schiffe strvchte an siniv chnie ### so rehte grimmer verge der chom dem Tronegær nie
###### 1558 | ### Do wolde er baz erzvrnen den vbermvten gast ### er slvch im einen schalten daz div gar cerbrast ### Hagen vber daz hovbet er was ein starcher man ### da von der Elsen verge grozen schaden da gewan [368a]
| ### Mit grimmegem mvte greif Hagen zehant ### vil balde ze siner scheiden da er ein waffen vant ### er slvch im ab daz hovbet vnd varf ez an den grvnt ### div mære wrden schiere den stolzen Bvrgonden <chvnt>
###### 1560 | ### In den selben stvnden do er den schifman slvch ### daz shiff daz vloz en owe daz was im leit genvch ### ê erz gerihte widere mveden er began ### do zoh vil chrefftechliche des chvenech Gventheres man
###### 1561 | ### Mit zvegen harte swinden chert ez der gast ### vnz im daz starche rvder in der <hende> brast ### er wolde zv den recken vz an einen sant ### da was deheinez mere hey wi schier erz da gebant
| ### Mit einem shilt vezel daz was ein porte smal ### gegen einem walde chert er hinze tal ### do vant er sinen herren an dem stade stan ### do gie im hin engegen vil manich wætlicher man
###### 1563 | ### Mit grvoze in wol enpfiengen di snellen ritter gvt ### do sahens in dem shiffe riechen daz blvt ### von einer starchen wnden di er dem vergen slvch ### do wart von den degenen gevraget Hagen genvch
###### 1564 | ### Do der kvenich Gventher daz heize blvt ersach ### sweben in dem shiffe wi balde er do sprach ### wan sagt ir mir Hagene war ist der verge chomen ### iwer starchez ellen ich wæn im daz leben hat benomen
| ### Do sprach er lovgenliche da ich daz shif da vant ### bi den wilden widen da lost ez min hant ### ich han deheinen vergen hivte hie gesehen ### ez ist ovch niemen leide von minen shvlden hi geschehen
###### 1566 | ### Do sprach von Bvrgonden der herre Gernot ### hivte mvz ich sorgen vf lieber frivnde tot ### sit wir der shifflivte bereite nine han ### wi wir chvmen veber des mvz ich trvrende stan
###### 1567 | ### Vil lvte rieff do Hagene leit nider vf daz gras ### ir chnehte div gereite ich gedenche daz ich was ### der aller beste verge den man bi dem Rine vant ### ia getrwe ich ivch wol bringen hinveber in Gelpfrades lant
| ### Daz si dester balder choemen veber flvt ### div ross si an slvgen daz swimmen daz wart gvt ### wand in div starch ven [368b] de deheinez da benam ### etelichez owete verre als ez mveden began
###### 1569 | ### Do trvgen si cem sheffe ir golt vnd ovh ir wat ### sit daz si der verte niht mohten haben rat ### Hagen was da meister des fvrt er vff den sant ### vil manegen richen recken in daz vnchvnde lant
###### 1570 | ### Zem ersten braht er veber wol tvsent ritter her ### dar nach sine recken dannoch was ir mer ### nivn tvsent knehte fvrt er an daz lant ### des tages was vnmvezech des Tronegeres hant
| ### Do er si wol gesvnde brahte veber den flvt ### do gedahte vremder mære der snelle degen gvt ### div im ê da sageten div wilden merwip ### des het des chvneges kapelan nach verlorn sinen lip
###### 1572 | ### Bi dem kappelsavme er den pfaffen vant ### ob dem heilchtvme er leinte an siner hant ### des moht er niht genizen do in Hagen sach ### der gotes arme prieister mvose liden vngemach
###### 1573 | ### Er swang in vz dem shiffe dar zv wart im gach ### do rieffen ir genvge <nv> vaha herre vach ### Giselher der ivnge zvernen erz began ### ern wold iz doh niht lazzen ir deheinen vnderstan
| ### Do sprach von Bvrgonden der herre Gernot ### waz hilffet ivh nv Hagene des kappelanes tot ### tæt ez ander iemen daz sold iv wesen leit ### vmbe welhe shvlde habt ir dem priester widerseit
###### 1575 | ### Der pfaffe swam genote er wolde sin genesen ### ob im iemen hvelfe des mohte da niht wesen ### wan der starche Hagene vil zornech was gemvt ### er stiez in zv dem grvnde daz dvhte niemene gvt
###### 1576 | ### Do der arme pfaffe der helfe nine sach ### do chert er wider vebere des leid er vngemach ### swi er niht swimmen chvnde im half div gotes hant ### daz er wol <chom> gesvnder hin wider vz an daz lant
| ### Do stvnt der arme priester vnde schvtte sine wat ### da bi sach wol Hagen daz sin niht wære rat ### daz im fver war sageten div wilden merewip ### er dahte dise degene mvezen verliesen den lip
###### 1578 | ### Do si daz shif entlvden vnd gar getrvgen dan ### swaz dar vf heten der drier [369a] chvenege man ### Hagen slvch ez ce stvchen vnd warfez an den flvt ### des het michel wnder di recken chvene vnde gvt
###### 1579 | ### Zwiv tvt ir daz brvder so sprach Danchwart ### wi svl wir veber so wir di widervart ### riten von den Hivnen ze lande an den Rin ### sit do sagete in Hagene daz des chvnde niht gesin
| ### Do sprach der helt von Tronege ich tvn iz vf den wan ### ob wir an dirre reise deheinen zagen han ### der vns entrinnen welle dvrch zægeliche not ### der mvz an diesem wæge doch liden schameliche tot
###### 1581 | ### Si fvrten mit in einen vz Bvrgonden lant ### einen helt ce sinen handen der was Volker genant ### der redete spæheliche allen sinen mvt ### swaz ie begie der Hagene daz dvht den videlære gvt
###### 1582 | ### Ir ross bereitet waren di sovmer wol geladen ### si heten an der verte noch deheinen schaden ### genomen der si mvete wan des kveneges chappelan ### der mvse vffe sinen fvezen hin wider zv dem Rine gan

<<< Übersicht <<< vorige Seite nächste Seite >>>